@@ -1,6 +1,13 @@
-/* demo/grph1/sgpack/sgpk05.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -64,44 +71,44 @@ static integer c__20 = 20;
     }
     sglnv_(&xc, &c_b8, &xc, &c_b9);
     sgtxv_(&xc, y, "SGTXV TEST", (ftnlen)10);
-/* <-- ƥ 1  */
+/* <-- テキスト 1 */
     sgstxi_(&c__2);
-/* <-- ƥ INDEX  */
+/* <-- テキスト INDEX */
     sgtxv_(&xc, &y[1], "INDEX2", (ftnlen)6);
-/* <-- ƥ 2  */
+/* <-- テキスト 2 */
     sgstxi_(&c__3);
-/* <-- ƥ INDEX  */
+/* <-- テキスト INDEX */
     sgtxv_(&xc, &y[2], "INDEX3", (ftnlen)6);
-/* <-- ƥ 3  */
+/* <-- テキスト 3 */
     sgstxi_(&c__4);
     sgstxs_(&c_b16);
-/* <-- ƥ SIZE  () */
+/* <-- テキスト SIZE */
     sgtxv_(&xc, &y[3], "SMALL", (ftnlen)5);
-/* <-- ƥ 4  */
+/* <-- テキスト 4 */
     sgstxs_(&c_b18);
-/* <-- ƥ SIZE  () */
+/* <-- テキスト SIZE */
     sgtxv_(&xc, &y[4], "LARGE", (ftnlen)5);
-/* <-- ƥ 5  */
+/* <-- テキスト 5 */
     sgstxs_(&c_b8);
     sgstxi_(&c__5);
     sgstxc_(&c_n1);
-/* <-- · */
+/* <-- */
     sgtxv_(&xc, &y[5], "LEFT", (ftnlen)4);
-/* <-- ƥ 6  */
+/* <-- テキスト 6 */
     sgstxc_(&c__0);
-/* <-- · */
+/* <-- */
     sgtxv_(&xc, &y[6], "CENTER", (ftnlen)6);
-/* <-- ƥ 7  */
+/* <-- テキスト 7 */
     sgstxc_(&c__1);
-/* <-- · */
+/* <-- */
     sgtxv_(&xc, &y[7], "RIGHT", (ftnlen)5);
-/* <-- ƥ 8  */
+/* <-- テキスト 8 */
     sgstxc_(&c__0);
     sgstxi_(&c__4);
     sgstxr_(&c__20);
-/* <-- ƥȲž */
+/* <-- */
     sgtxv_(&xc, &y[8], "ROTATION", (ftnlen)8);
-/* <-- ƥ 9  */
+/* <-- テキスト 9 */
     sgcls_();
     return 0;
 } /* MAIN__ */
