@@ -1,6 +1,13 @@
-/* demo/grph1/sgpack/sgpk08.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -77,7 +84,7 @@ static integer c__601 = 601;
     e_rsle();
     sgopn_(&iws);
     sglset_("LSOFTF", &c_true, (ftnlen)6);
-/* <-- եȥեλ */
+/* <-- */
     sgfrm_();
     sgswnd_(&c_b11, &c_b12, &c_b11, &c_b12);
     sgsvpt_(&c_b15, &c_b16, &c_b15, &c_b16);
@@ -85,20 +92,20 @@ static integer c__601 = 601;
     sgstrf_();
     sgplu_(&c__3, upx3, upy3);
     sgtnu_(&c__3, upx3, upy3);
-/* <-- ֤ () */
+/* <-- 網かけ (左下) */
     sgsvpt_(&c_b15, &c_b16, &c_b16, &c_b12);
     sgstrf_();
     sgstnp_(&c__101);
     sgtnu_(&c__6, upx6, upy6);
-/* <--  () */
+/* <-- 横線 (左上) */
     sgsvpt_(&c_b16, &c_b12, &c_b15, &c_b16);
     sgstrf_();
     sgtnzu_(&c__6, upx6, upy6, &c__201);
-/* <--  () */
+/* <-- 斜線 (右下) */
     sgsvpt_(&c_b16, &c_b12, &c_b16, &c_b12);
     sgstrf_();
     sgtnzu_(&c__61, upxs, upys, &c__601);
-/* <--  () */
+/* <-- 横線 (右上) */
     sgcls_();
     return 0;
 } /* MAIN__ */
