@@ -1,6 +1,13 @@
-/* demo/rakuraku/kihon/kihon4.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -55,34 +62,34 @@ static integer c_n10 = -10;
     e_rsle();
     sgopn_(&iws);
     sgfrm_();
-/* --  ---- */
+/* -- 罫線 ---- */
     for (n = 1; n <= 9; ++n) {
 	y[n - 1] = (10 - n) * .1f;
 	sglnv_(&c_b7, &y[n - 1], &c_b8, &y[n - 1]);
 /* L10: */
     }
     sglnv_(&c_b9, &c_b10, &c_b9, &c_b12);
-/* -- ǥե ---- */
+/* -- デフォルト ---- */
     sgtxv_(&c_b9, y, "SGTXV", (ftnlen)5);
-/* -- ʸΥ饤󥤥ǥ ---- */
+/* -- 文字のラインインデクス ---- */
     sgstxi_(&c__3);
     sgtxv_(&c_b9, &y[1], "INDEX3", (ftnlen)6);
     sgstxi_(&c__5);
     sgtxv_(&c_b9, &y[2], "INDEX5", (ftnlen)6);
     sgstxi_(&c__1);
-/* -- ʸ礭 ---- */
+/* -- 文字の大きさ ---- */
     sgstxs_(&c_b22);
     sgtxv_(&c_b9, &y[3], "SMALL", (ftnlen)5);
     sgstxs_(&c_b25);
     sgtxv_(&c_b9, &y[4], "LARGE", (ftnlen)5);
     sgstxs_(&c_b10);
-/* -- ʸΥ󥿥󥰥ץ ---- */
+/* -- 文字列のセンタリングオプション ---- */
     sgstxc_(&c_n1);
     sgtxv_(&c_b9, &y[5], "LEFT", (ftnlen)4);
     sgstxc_(&c__1);
     sgtxv_(&c_b9, &y[6], "RIGHT", (ftnlen)5);
     sgstxc_(&c__0);
-/* -- ʸβž ---- */
+/* -- 文字列の回転角 ---- */
     sgstxr_(&c__10);
     sgtxv_(&c_b9, &y[7], "ROTATION+", (ftnlen)9);
     sgstxr_(&c_n10);
