@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -15,7 +15,7 @@
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__14 = 14;
+static integer c__16 = 16;
 
 /* ----------------------------------------------------------------------- */
 /*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
@@ -25,38 +25,41 @@ static integer c__14 = 14;
 {
     /* Initialized data */
 
-    static char cparas[8*14] = "WSNAME01" "WSNAME02" "WSNAME03" "WSNAME04" 
-	    "FNAME   " "TITLE   " "CLRMAP  " "BITMAP  " "CL2TN   " "FONT1   " 
-	    "FONT2   " "LPR     " "CIMGFMT " "CMAPLIST";
-    static char cx[80*14] = "X                                              "
-	    "                                 " "PS                          "
-	    "                                                    " "Tek      "
+    static char cparas[8*16] = "WSNAME01" "WSNAME02" "FNAME   " "TITLE   " 
+	    "CLRMAP  " "BITMAP  " "CL2TN   " "FONT1   " "FONT2   " "LPR     " 
+	    "CIMGFMT " "CMAPLIST" "FLNAME01" "FLNAME02" "FLNAME03" "FLNAME04";
+    static char cx[80*16] = "DISP                                           "
+	    "                                 " "FILES                       "
+	    "                                                    " "dcl      "
 	    "                                                                "
-	    "       " "Gtk                                                   "
-	    "                          " "dcl                                "
-	    "                                             " "*               "
+	    "       " "*                                                     "
+	    "                          " "colormap                           "
+	    "                                             " "bitmap          "
 	    "                                                                " 
-	    "colormap                                                       "
-	    "                 " "bitmap                                      "
-	    "                                    " "cl2tnmap                 "
-	    "                                                       " "font1u"
+	    "cl2tnmap                                                       "
+	    "                 " "font1u                                      "
+	    "                                    " "font2u                   "
+	    "                                                       " "lpr   "
 	    "                                                                "
-	    "          " "font2u                                             "
-	    "                             " "lpr                             "
-	    "                                                " "png          "
+	    "          " "png                                                "
+	    "                             " "cmaplist                        "
+	    "                                                " "PNG          "
 	    "                                                                "
-	    "   " "cmaplist                                                  "
-	    "                      ";
-    static char cparal[40*14] = "DEVICE_NAME01                           " 
-	    "DEVICE_NAME02                           " "DEVICE_NAME03       "
-	    "                    " "DEVICE_NAME04                           " 
-	    "FRAME_NAME                              " "TITLE               "
-	    "                    " "COLORMAP                                " 
-	    "BITMAP                                  " "COLOR_TO_TONE_MAP   "
-	    "                    " "FONT1                                   " 
-	    "FONT2                                   " "LPR                 "
-	    "                    " "IMAGE_FORMAT                            " 
-	    "COLORMAP_LIST                           ";
+	    "   " "EPS                                                       "
+	    "                      " "SVG                                    "
+	    "                                         " "PDF                 "
+	    "                                                            ";
+    static char cparal[40*16] = "DEVICE_NAME01                           " 
+	    "DEVICE_NAME02                           " "FRAME_NAME          "
+	    "                    " "TITLE                                   " 
+	    "COLORMAP                                " "BITMAP              "
+	    "                    " "COLOR_TO_TONE_MAP                       " 
+	    "FONT1                                   " "FONT2               "
+	    "                    " "LPR                                     " 
+	    "IMAGE_FORMAT                            " "COLORMAP_LIST       "
+	    "                    " "FILE_NAME01                             " 
+	    "FILE_NAME02                             " "FILE_NAME03         "
+	    "                    " "FILE_NAME04                             ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -86,12 +89,12 @@ static integer c__14 = 14;
 	case 6: goto L_swcqin;
 	}
 
-    *ncp = 14;
+    *ncp = 16;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swcqid:
-    for (n = 1; n <= 14; ++n) {
+    for (n = 1; n <= 16; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -109,7 +112,7 @@ L_swcqid:
 /* ----------------------------------------------------------------------- */
 
 L_swcqcp:
-    if (1 <= *idx && *idx <= 14) {
+    if (1 <= *idx && *idx <= 16) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SWCQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -119,7 +122,7 @@ L_swcqcp:
 /* ----------------------------------------------------------------------- */
 
 L_swcqcl:
-    if (1 <= *idx && *idx <= 14) {
+    if (1 <= *idx && *idx <= 16) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SWCQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -130,11 +133,11 @@ L_swcqcl:
 
 L_swcqvl:
     if (lfirst) {
-	rtcget_("SW", cparas, cx, &c__14, (ftnlen)2, (ftnlen)8, (ftnlen)80);
-	rlcget_(cparal, cx, &c__14, (ftnlen)40, (ftnlen)80);
+	rtcget_("SW", cparas, cx, &c__16, (ftnlen)2, (ftnlen)8, (ftnlen)80);
+	rlcget_(cparal, cx, &c__16, (ftnlen)40, (ftnlen)80);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 14) {
+    if (1 <= *idx && *idx <= 16) {
 	s_copy(cval, cx + (*idx - 1) * 80, cval_len, (ftnlen)80);
     } else {
 	msgdmp_("E", "SWCQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -145,11 +148,11 @@ L_swcqvl:
 
 L_swcsvl:
     if (lfirst) {
-	rtcget_("SW", cparas, cx, &c__14, (ftnlen)2, (ftnlen)8, (ftnlen)80);
-	rlcget_(cparal, cx, &c__14, (ftnlen)40, (ftnlen)80);
+	rtcget_("SW", cparas, cx, &c__16, (ftnlen)2, (ftnlen)8, (ftnlen)80);
+	rlcget_(cparal, cx, &c__16, (ftnlen)40, (ftnlen)80);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 14) {
+    if (1 <= *idx && *idx <= 16) {
 	s_copy(cx + (*idx - 1) * 80, cval, (ftnlen)80, cval_len);
     } else {
 	msgdmp_("E", "SWCSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -159,7 +162,7 @@ L_swcsvl:
 /* ----------------------------------------------------------------------- */
 
 L_swcqin:
-    for (n = 1; n <= 14; ++n) {
+    for (n = 1; n <= 16; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
