@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -15,6 +15,7 @@
 /* Table of constant values */
 
 static integer c__3 = 3;
+static integer c__2 = 2;
 
 /* ----------------------------------------------------------------------- */
 /*     REAL PARAMETER CONTROL */
@@ -24,19 +25,32 @@ static integer c__3 = 3;
 /* Subroutine */ int swrqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	real *rpara, integer *in, ftnlen cp_len)
 {
+    /* Initialized data */
+
+    static char cparas[8*2] = "RIMGCMP " "RLWFACT ";
+    static real rx[2] = { -1.f,.2f };
+    static char cparal[40*2] = "IMAGE_COMPRESSION                       " 
+	    "LINE_WIDTH_FACTOR                       ";
+    static logical lfirst = TRUE_;
+
     /* System generated locals */
     address a__1[3];
     integer i__1[3];
 
     /* Builtin functions */
-    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
+    /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen),
+	     s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
+    extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
-	    ftnlen, ftnlen);
+	    ftnlen, ftnlen), rlrget_(char *, real *, integer *, ftnlen), 
+	    rtrget_(char *, char *, real *, integer *, ftnlen, ftnlen);
 
+/*     / SHORT NAME / */
     switch(n__) {
 	case 1: goto L_swrqid;
 	case 2: goto L_swrqcp;
@@ -46,12 +60,20 @@ static integer c__3 = 3;
 	case 6: goto L_swrqin;
 	}
 
-    *ncp = 0;
+/*    / LONG NAME / */
+    *ncp = 2;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swrqid:
-    *idx = 0;
+    for (n = 1; n <= 2; ++n) {
+	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
+		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
+	    *idx = n;
+	    return 0;
+	}
+/* L10: */
+    }
 /* Writing concatenation */
     i__1[0] = 11, a__1[0] = "PARAMETER '";
     i__1[1] = lenc_(cp, cp_len), a__1[1] = cp;
@@ -62,31 +84,64 @@ L_swrqid:
 /* ----------------------------------------------------------------------- */
 
 L_swrqcp:
-    msgdmp_("E", "SWRQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
-	    ftnlen)20);
+    if (1 <= *idx && *idx <= 2) {
+	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
+    } else {
+	msgdmp_("E", "SWRQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
+		ftnlen)20);
+    }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swrqcl:
-    msgdmp_("E", "SWRQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
-	    ftnlen)20);
+    if (1 <= *idx && *idx <= 2) {
+	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
+    } else {
+	msgdmp_("E", "SWRQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
+		ftnlen)20);
+    }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swrqvl:
-    *rpara = 0.f;
-    msgdmp_("E", "SWRQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
-	    ftnlen)20);
+    if (lfirst) {
+	rtrget_("SW", cparas, rx, &c__2, (ftnlen)2, (ftnlen)8);
+	rlrget_(cparal, rx, &c__2, (ftnlen)40);
+	lfirst = FALSE_;
+    }
+    if (1 <= *idx && *idx <= 2) {
+	*rpara = rx[*idx - 1];
+    } else {
+	msgdmp_("E", "SWRQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
+		ftnlen)20);
+    }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swrsvl:
-    msgdmp_("E", "SWRSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
-	    ftnlen)20);
+    if (lfirst) {
+	rtrget_("SW", cparas, rx, &c__2, (ftnlen)2, (ftnlen)8);
+	rlrget_(cparal, rx, &c__2, (ftnlen)40);
+	lfirst = FALSE_;
+    }
+    if (1 <= *idx && *idx <= 2) {
+	rx[*idx - 1] = *rpara;
+    } else {
+	msgdmp_("E", "SWRSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
+		ftnlen)20);
+    }
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swrqin:
+    for (n = 1; n <= 2; ++n) {
+	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
+		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
+	    *in = n;
+	    return 0;
+	}
+/* L20: */
+    }
     *in = 0;
     return 0;
 } /* swrqnp_ */
