@@ -1,6 +1,13 @@
-/* src/grph1/szpack/szlaop.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -34,7 +41,7 @@ static integer c__1 = 1;
     /* Local variables */
     static logical ldeg;
     static char cobj[80];
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int cdblk_(char *, ftnlen);
     static integer iatone;
     extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
