@@ -1,6 +1,13 @@
-/* src/grph2/ucpack/ucxamn.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -86,6 +93,10 @@ static integer c__9 = 9;
 	iml = ndmon_(&iyi, &moi);
 	if (idi == iml || i__ == *nd) {
 	    ++nn;
+	    if (nn > 50) {
+		msgdmp_("E", "UCXAMN", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    ux[nn - 1] = (real) i__;
 	    s_copy(ch + (nn - 2) * 9, " ", (ftnlen)9, (ftnlen)1);
 	    cmon_(ch__1, (ftnlen)9, &moi);
@@ -96,10 +107,6 @@ static integer c__9 = 9;
 	}
 /* L10: */
     }
-    if (nn > 50) {
-	msgdmp_("E", "UCXAMN", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
-    }
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTX";
     i__2[1] = 1, a__1[1] = cside;
