@@ -1,6 +1,13 @@
-/* src/grph2/ucpack/ucyayr.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -38,13 +45,16 @@ static integer c__4 = 4;
     static char ch[4*50];
     static integer nn;
     static real uy[50];
-    static integer id0, mo0, iy0, idi, moi, iyi, iyl, itdi;
+    static integer id0, mo0, iy0;
+    static real vx1, vx2, vy1, vy2;
+    static integer idi, moi, iyi, iyl, itdi, nchx;
     extern /* Subroutine */ int cladj_(char *, ftnlen);
     static logical label;
     extern /* Subroutine */ int date13_(integer *, integer *, integer *, 
 	    integer *), date32_(integer *, integer *, integer *, integer *);
     static integer icent, irota, irotc;
     static logical lbtwn;
+    static real rsize;
     extern /* Subroutine */ int datef3_(integer *, integer *, integer *, 
 	    integer *, integer *, integer *, integer *);
     static real rtick2;
@@ -55,10 +65,10 @@ static integer c__4 = 4;
     extern /* Subroutine */ int uziget_(char *, integer *, ftnlen), uyplbl_(
 	    char *, integer *, real *, char *, integer *, integer *, ftnlen, 
 	    ftnlen), uzlget_(char *, logical *, ftnlen), uzrget_(char *, real 
-	    *, ftnlen), uziset_(char *, integer *, ftnlen), uzlset_(char *, 
-	    logical *, ftnlen), uypaxs_(char *, integer *, ftnlen), uyptmk_(
-	    char *, integer *, real *, integer *, ftnlen), uzrset_(char *, 
-	    real *, ftnlen);
+	    *, ftnlen), uziset_(char *, integer *, ftnlen), sgqvpt_(real *, 
+	    real *, real *, real *), uzlset_(char *, logical *, ftnlen), 
+	    uypaxs_(char *, integer *, ftnlen), uyptmk_(char *, integer *, 
+	    real *, integer *, ftnlen), uzrset_(char *, real *, ftnlen);
 
     if (! luychk_(cside, (ftnlen)1)) {
 	msgdmp_("E", "UCYAYR", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
@@ -83,6 +93,10 @@ static integer c__4 = 4;
 	iyl = ndyear_(&iyi);
 	if (itdi == iyl || i__ == *nd) {
 	    ++nn;
+	    if (nn > 50) {
+		msgdmp_("E", "UCYAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    uy[nn - 1] = (real) i__;
 	    ici__1.icierr = 0;
 	    ici__1.icirnum = 1;
@@ -96,10 +110,9 @@ static integer c__4 = 4;
 	}
 /* L10: */
     }
-    if (nn > 50) {
-	msgdmp_("E", "UCYAYR", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
-    }
+    sgqvpt_(&vx1, &vx2, &vy1, &vy2);
+    uzrget_("RSIZEL2", &rsize, (ftnlen)7);
+    nchx = (vy2 - vy1) / rsize;
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTY";
     i__2[1] = 1, a__1[1] = cside;
@@ -121,11 +134,19 @@ static integer c__4 = 4;
     i__2[1] = 1, a__1[1] = cside;
     s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
     uziset_(ch__1, &c__0, (ftnlen)7);
+    if (nn << 2 <= nchx) {
 /* Writing concatenation */
-    i__2[0] = 6, a__1[0] = "IROTLY";
-    i__2[1] = 1, a__1[1] = cside;
-    s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
-    uziset_(ch__1, &irotc, (ftnlen)7);
+	i__2[0] = 6, a__1[0] = "IROTLY";
+	i__2[1] = 1, a__1[1] = cside;
+	s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
+	uziset_(ch__1, &irotc, (ftnlen)7);
+    } else {
+/* Writing concatenation */
+	i__2[0] = 6, a__1[0] = "IROTLY";
+	i__2[1] = 1, a__1[1] = cside;
+	s_cat(ch__1, a__1, i__2, &c__2, (ftnlen)7);
+	uziset_(ch__1, &c__0, (ftnlen)7);
+    }
     uzlset_("LBTWN", &c_true, (ftnlen)5);
     uzrget_("RSIZET2", &rtick2, (ftnlen)7);
     r__1 = rtick2 * 1.5f;
