@@ -1,6 +1,13 @@
-/* src/grph2/udpack/uduxuy.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -20,12 +27,11 @@
     static real cc, xd1, xd2, yd1, yd2;
     static integer ix1, ix2, iy1, iy2;
     static real zz1, zz2;
-    extern doublereal ruwgx_(integer *), ruwgy_(integer *), rudval_(real *, 
-	    real *);
+    extern real ruwgx_(integer *), ruwgy_(integer *), rudval_(real *, real *);
 
     /* Parameter adjustments */
     z_dim1 = *mx;
-    z_offset = 1 + z_dim1 * 1;
+    z_offset = 1 + z_dim1;
     z__ -= z_offset;
 
     /* Function Body */
