@@ -1,6 +1,13 @@
-/* src/grph2/uspack/usysub.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -164,7 +171,7 @@ static logical c_false = FALSE_;
 	i__1[1] = 1, a__1[1] = cxs;
 	s_cat(cp, a__1, i__1, &c__2, (ftnlen)8);
 	usrget_(cp, &roffx, (ftnlen)8);
-	roffx = dmax(rsoff,roffx);
+	roffx = max(rsoff,roffx);
 /* ----------------------------------------------------------------------- */
 /*       IFLAG =  1 : LABEL IS RIGHT SIDE OF THE AXIS. */
 /*       IFLAG = -1 : LABEL IS LEFT  SIDE OF THE AXIS. */
@@ -221,7 +228,7 @@ static logical c_false = FALSE_;
 	    }
 	}
 	icenty = icy / ic;
-	posx = dabs(posx);
+	posx = abs(posx);
     }
     sglget_("LCLIP", &lclipz, (ftnlen)5);
     sglset_("LCLIP", &c_false, (ftnlen)5);
