@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -28,7 +28,7 @@ static integer c__3 = 3;
 
     static char cparas[8*3] = "UMIN    " "UMAX    " "UREF    ";
     static integer itype[3] = { 3,3,3 };
-    static char cparal[8*3] = "****UMIN" "****UMAX" "****UREF";
+    static char cparal[12*3] = "****UMIN    " "****UMAX    " "****UREF    ";
 
     /* System generated locals */
     address a__1[3];
@@ -69,7 +69,7 @@ static integer c__3 = 3;
 L_uupqid:
     for (n = 1; n <= 3; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
-		cp, cparal + (n - 1 << 3), cp_len, (ftnlen)8)) {
+		cp, cparal + (n - 1) * 12, cp_len, (ftnlen)12)) {
 	    *idx = n;
 	    return 0;
 	}
@@ -96,7 +96,7 @@ L_uupqcp:
 
 L_uupqcl:
     if (1 <= *idx && *idx <= 3) {
-	s_copy(cp, cparal + (*idx - 1 << 3), cp_len, (ftnlen)8);
+	s_copy(cp, cparal + (*idx - 1) * 12, cp_len, (ftnlen)12);
     } else {
 	msgdmp_("E", "UUPQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
 		ftnlen)20);
@@ -155,7 +155,7 @@ L_uupsvl:
 L_uupqin:
     for (n = 1; n <= 3; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
-		cp, cparal + (n - 1 << 3), cp_len, (ftnlen)8)) {
+		cp, cparal + (n - 1) * 12, cp_len, (ftnlen)12)) {
 	    *in = n;
 	    return 0;
 	}
