@@ -1,6 +1,13 @@
-/* src/grph2/uvpack/uvdifz.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -170,8 +177,8 @@ static integer c__1 = 1;
 		szsttv_(&vxp, &vy2p);
 		szcltv_();
 	    } else {
-		dyp = (r__1 = vy2p - vy1p, dabs(r__1));
-		dyn = (r__1 = vy2n - vy1n, dabs(r__1));
+		dyp = (r__1 = vy2p - vy1p, abs(r__1));
+		dyn = (r__1 = vy2n - vy1n, abs(r__1));
 		vxc = (vxp * dyn + vxn * dyp) / (dyp + dyn);
 		vyc = (vy1p * dyn + vy1n * dyp) / (dyp + dyn);
 		if (vy2p >= vy1p) {
