@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -34,8 +34,11 @@ integer lenz_(char *c__, ftnlen c_len)
     *(unsigned char *)cs = ' ';
     n = i_len(c__, c_len);
 L15:
-    lchar = n >= 1 && (*(unsigned char *)&c__[n - 1] == *(unsigned char *)cn 
-	    || *(unsigned char *)&c__[n - 1] == *(unsigned char *)cs);
+    if (n < 1) {
+	goto L10;
+    }
+    lchar = *(unsigned char *)&c__[n - 1] == *(unsigned char *)cn || *(
+	    unsigned char *)&c__[n - 1] == *(unsigned char *)cs;
     if (! lchar) {
 	goto L10;
     }
