@@ -1,6 +1,13 @@
-/* src/math1/gt2dlib/g2ibl2.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -88,7 +95,7 @@ static real c_b18 = 1.f;
 	    } else {
 		msgdmp_("W", "G2IBLI", "NO SOLUTION IN THE DOMAIN", (ftnlen)1,
 			 (ftnlen)6, (ftnlen)25);
-		if (dabs(p1) < dabs(p2)) {
+		if (abs(p1) < abs(p2)) {
 		    *p = p1;
 		} else {
 		    *p = p2;
@@ -130,7 +137,7 @@ static real c_b18 = 1.f;
 	    } else {
 		msgdmp_("W", "G2IBLI", "NO SOLUTION IN THE DOMAIN", (ftnlen)1,
 			 (ftnlen)6, (ftnlen)25);
-		if (dabs(p1) < dabs(p2)) {
+		if (abs(p1) < abs(p2)) {
 		    *p = p1;
 		} else {
 		    *p = p2;
@@ -180,7 +187,7 @@ static real c_b18 = 1.f;
 		    } else {
 			msgdmp_("W", "G2IBLI", "NO SOLUTION IN THE DOMAIN", (
 				ftnlen)1, (ftnlen)6, (ftnlen)25);
-			if (dabs(p1) < dabs(p2)) {
+			if (abs(p1) < abs(p2)) {
 			    *p = p1;
 			} else {
 			    *p = p2;
