@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfcyl.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -14,9 +21,9 @@
 	*y)
 {
     static real pi, rna;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
 
     switch(n__) {
 	case 1: goto L_mpicyl;
@@ -38,7 +45,7 @@ L_mpicyl:
     pi = rfpi_();
     *xlon = *x;
     *ylat = *y;
-    if (dabs(*xlon) <= pi && dabs(*ylat) <= pi / 2) {
+    if (abs(*xlon) <= pi && abs(*ylat) <= pi / 2) {
 	return 0;
     }
     glrget_("RUNDEF", &rna, (ftnlen)6);
