@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfek6.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -18,11 +25,11 @@
 
     /* Local variables */
     static real b, pi, phi, rna;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     static real alpha;
     extern /* Subroutine */ int mpzek6_();
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
     extern /* Subroutine */ int mpznwt_(U_fp, real *, real *);
 
     switch(n__) {
@@ -41,10 +48,10 @@ L_mpiek6:
     pi = rfpi_();
     b = (pi + 2) / 2;
     alpha = *y / .8820255f;
-    if (dabs(alpha) <= pi / 2) {
+    if (abs(alpha) <= pi / 2) {
 	phi = asin((alpha + sin(alpha)) / b);
 	*xlon = *x * 2 / .8820255f / (cos(alpha) + 1);
-	if (dabs(*xlon) <= pi) {
+	if (abs(*xlon) <= pi) {
 	    *ylat = phi;
 	    return 0;
 	}
